@@ -3,7 +3,7 @@ package chroma
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
+	"github.com/stretchr/testify/assert"
 )
 
 func TestInclude(t *testing.T) {
@@ -44,7 +44,7 @@ func TestInclude(t *testing.T) {
 }
 
 func TestCombine(t *testing.T) {
-	l := MustNewLexer(nil, Rules{
+	l := MustNewLexer(nil, Rules{ // nolint: forbidigo
 		"root":  {{`hello`, String, Combined("world", "bye", "space")}},
 		"world": {{`world`, Name, nil}},
 		"bye":   {{`bye`, Name, nil}},
